=== modified file 'Makefile.am'
--- Makefile.am	2008-12-25 02:00:12 +0000
+++ Makefile.am	2008-12-31 22:08:15 +0000
@@ -5,6 +5,8 @@
 # Use and distribution licensed under the BSD license.  See
 # the COPYING file in this directory for full text.
 
+ACLOCAL_AMFLAGS= -I m4
+
 SUBDIRS = libgearman gearmand tests examples
 
 docs: all

=== added directory 'm4'
=== added file 'm4/extensions.m4'
--- m4/extensions.m4	1970-01-01 00:00:00 +0000
+++ m4/extensions.m4	2008-12-31 22:08:15 +0000
@@ -0,0 +1,37 @@
+dnl Provide AC_USE_SYSTEM_EXTENSIONS for old autoconf machines.
+AC_DEFUN([ACX_USE_SYSTEM_EXTENSIONS],[
+  ifdef([AC_USE_SYSTEM_EXTENSIONS],[
+    AC_USE_SYSTEM_EXTENSIONS
+  ],[
+    AC_BEFORE([$0], [AC_COMPILE_IFELSE])
+    AC_BEFORE([$0], [AC_RUN_IFELSE])
+
+    AC_REQUIRE([AC_GNU_SOURCE])
+    AC_REQUIRE([AC_AIX])
+    AC_REQUIRE([AC_MINIX])
+
+    AH_VERBATIM([__EXTENSIONS__],
+[/* Enable extensions on Solaris.  */
+#ifndef __EXTENSIONS__
+# undef __EXTENSIONS__
+#endif
+#ifndef _POSIX_PTHREAD_SEMANTICS
+# undef _POSIX_PTHREAD_SEMANTICS
+#endif
+#ifndef _TANDEM_SOURCE
+# undef _TANDEM_SOURCE
+#endif])
+    AC_CACHE_CHECK([whether it is safe to define __EXTENSIONS__],
+      [ac_cv_safe_to_define___extensions__],
+      [AC_COMPILE_IFELSE(
+         [AC_LANG_PROGRAM([
+#           define __EXTENSIONS__ 1
+            AC_INCLUDES_DEFAULT])],
+         [ac_cv_safe_to_define___extensions__=yes],
+         [ac_cv_safe_to_define___extensions__=no])])
+    test $ac_cv_safe_to_define___extensions__ = yes &&
+      AC_DEFINE([__EXTENSIONS__])
+    AC_DEFINE([_POSIX_PTHREAD_SEMANTICS])
+    AC_DEFINE([_TANDEM_SOURCE])
+  ])
+])

=== added file 'm4/search_for_lib.m4'
--- m4/search_for_lib.m4	1970-01-01 00:00:00 +0000
+++ m4/search_for_lib.m4	2008-12-31 22:08:15 +0000
@@ -0,0 +1,104 @@
+dnl
+dnl Copyright (C) 2008 Sun Microsystems
+dnl 
+dnl This program is free software; you can redistribute it and/or modify
+dnl it under the terms of the GNU General Public License as published by
+dnl the Free Software Foundation; version 2 of the License.
+dnl 
+dnl This program is distributed in the hope that it will be useful,
+dnl but WITHOUT ANY WARRANTY; without even the implied warranty of
+dnl MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+dnl GNU General Public License for more details.
+dnl 
+dnl You should have received a copy of the GNU General Public License
+dnl along with this program; if not, write to the Free Software
+dnl Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+dnl
+dnl SEARCH_FOR_LIB(LIB, FUNCTIONS, FUNCTION,
+dnl                [ACTION-IF-NOT-FOUND],
+dnl                [LIBS_TO_ADD])
+
+AC_DEFUN([SEARCH_FOR_LIB],
+[
+  AS_VAR_PUSHDEF([with_lib], [with_$1])
+  AS_VAR_PUSHDEF([ac_header], [ac_cv_header_$3])
+  AS_VAR_PUSHDEF([have_lib], [ac_cv_have_$1])
+  AS_VAR_PUSHDEF([libs_var], AS_TR_CPP([$1_LIBS]))
+  AS_VAR_PUSHDEF([cflags_var], AS_TR_CPP([$1_CFLAGS]))
+  AS_VAR_PUSHDEF([path_var], AS_TR_CPP([$1_PATH]))
+  AS_LITERAL_IF([$1],
+                [AS_VAR_PUSHDEF([ac_lib], [ac_cv_lib_$1_$2])],
+                [AS_VAR_PUSHDEF([ac_lib], [ac_cv_lib_$1''_$2])])
+
+  AS_IF([test "x$prefix" = "xNONE"],
+    [AS_VAR_SET([path_var],["$ac_default_prefix"])],
+    [AS_VAR_SET([path_var],["$prefix"])])
+
+
+  AC_ARG_WITH([$1],
+    [AS_HELP_STRING([--with-$1@<:@=DIR@:>@],
+       [Use lib$1 in DIR])],
+    [ AS_VAR_SET([with_lib], [$withval]) ],
+    [ AS_VAR_SET([with_lib], [yes]) ])
+
+  AS_IF([test AS_VAR_GET([with_lib]) = yes],[
+    AC_CHECK_HEADERS([$3])
+
+    my_save_LIBS="$LIBS"
+    LIBS="$5"
+    AC_CHECK_LIB($1, $2)
+    AS_VAR_SET([libs_var],[${LIBS}])
+    LIBS="${my_save_LIBS}"
+    AS_VAR_SET([cflags_var],[""])
+    AS_IF([test AS_VAR_GET([ac_header]) = "$3" -a AS_VAR_GET([ac_lib]) = yes],
+      [AS_VAR_SET([have_lib],[yes])
+       AS_VAR_SET([path_var],[$PATH])
+      ],
+      [AS_VAR_SET([have_lib],[no])
+       AS_VAR_SET([with_lib],["AS_VAR_GET([path_var]) /usr/local /opt/csw /opt/local"])
+      ])
+  ])
+  AS_IF([test "AS_VAR_GET([with_lib])" != yes],[
+   for libloc in AS_VAR_GET([with_lib])
+   do
+    AC_MSG_CHECKING(for $1 in $libloc)
+    if test -f $libloc/$3 -a -f $libloc/lib$1.a
+    then
+      owd=`pwd`
+      if cd $libloc; then libloc=`pwd`; cd $owd; fi
+      AS_VAR_SET([cflags_var],[-I$libloc])
+      AS_VAR_SET([libs_var],["-L$libloc -l$1"])
+      AS_VAR_SET([path_var],["$libloc:$PATH"])
+      AS_VAR_SET([have_lib],[yes])
+      AC_MSG_RESULT([yes])
+      break
+    elif test -f $libloc/include/$3 -a -f $libloc/lib/lib$1.a; then
+      owd=`pwd`
+      if cd $libloc; then libloc=`pwd`; cd $owd; fi
+      AS_VAR_SET([cflags_var],[-I$libloc/include])
+      AS_VAR_SET([libs_var],["-L$libloc/lib -l$1"])
+      AS_VAR_SET([path_var],["$libloc/bin:$PATH"])
+      AS_VAR_SET([have_lib],[yes])
+      AC_MSG_RESULT([yes])
+      break
+    else
+      AC_MSG_RESULT([no])
+      AS_VAR_SET([have_lib],[no])
+    fi
+   done
+  ])
+  AS_IF([test AS_VAR_GET([have_lib]) = no],[
+    AC_MSG_WARN([$3 or lib$1.a not found. Try installing $1 developement packages])
+    $4
+  ])
+  AC_SUBST(libs_var)
+  AC_SUBST(cflags_var)
+  AC_SUBST(path_var)
+  AS_VAR_POPDEF([with_lib])
+  AS_VAR_POPDEF([ac_header])
+  AS_VAR_POPDEF([libs_var])
+  AS_VAR_POPDEF([cflags_var])
+  AS_VAR_POPDEF([path_var])
+  AS_VAR_POPDEF([have_lib])
+  AS_VAR_POPDEF([ac_lib])
+])    

